passwd:$6$0pnMdYaibTTW1eGy$okDJQvUQfKI7jtnoUhnWyCwwSZTRyPthNJJ.joSEstjQisy/xAj4Xn6ACvv4FJPXpGLJuGr/lZTWuge7L4kLb0
quota:0
homedir:/home/nommaded/mail/ventaparcelaschile.cl/avg
strength:100
lastchanged:-1
perms:rw
