passwd:$6$iI/T874ehUC9.jPu$8hhUrm9AsxrtBBaXKeUdp893uh2SRN.aPmFxgLZoRfpxZyhn6uZqOc0Tx/aTxqnzQ9xhM9YUZImfClDFLe84r.
quota:0
homedir:/home/nommaded/mail/ventaparcelaschile.cl/contacto
strength:100
lastchanged:-1
perms:rw
